@@ -10,8 +10,8 @@ import (
 	"sync"
 	"testing"
 
-	"github.com/google/mtail/internal/mtail"
-	"github.com/google/mtail/internal/testutil"
+	"github.com/jaqx0r/mtail/internal/mtail"
+	"github.com/jaqx0r/mtail/internal/testutil"
 )
 
 func TestBasicTail(t *testing.T) {
