@@ -11,8 +11,8 @@ import (
 	"testing"
 
 	"github.com/golang/glog"
-	"github.com/google/mtail/internal/mtail"
-	"github.com/google/mtail/internal/testutil"
+	"github.com/jaqx0r/mtail/internal/mtail"
+	"github.com/jaqx0r/mtail/internal/testutil"
 )
 
 // TestLogDeletion is a unix-only test because on Windows files with open read handles cannot be deleted.
