@@ -12,8 +12,8 @@ import (
 	"syscall"
 	"testing"
 
-	"github.com/google/mtail/internal/mtail"
-	"github.com/google/mtail/internal/testutil"
+	"github.com/jaqx0r/mtail/internal/mtail"
+	"github.com/jaqx0r/mtail/internal/testutil"
 	"golang.org/x/sys/unix"
 )
 
