@@ -610,7 +610,7 @@ func TestInstrs(t *testing.T) {
 				v.t.Push(item)
 			}
 			v.t.matches = make(map[int][]string)
-			v.input = logline.New(context.Background(), testFilename, "aaaab")
+			v.input = logline.New(context.Background(), testFilename, logline.GetHash(testFilename), "aaaab")
 			v.execute(v.t, tc.i)
 			if v.terminate {
 				t.Fatalf("Execution failed, see info log.")
@@ -632,7 +632,7 @@ func makeVM(i code.Instr, m []*metrics.Metric) *VM {
 	v.t = new(thread)
 	v.t.stack = make([]interface{}, 0)
 	v.t.matches = make(map[int][]string)
-	v.input = logline.New(context.Background(), testFilename, "aaaab")
+	v.input = logline.New(context.Background(), testFilename, logline.GetHash(testFilename), "aaaab")
 	return v
 }
 
