@@ -4,7 +4,7 @@
 package logstream
 
 import (
-	"github.com/google/mtail/internal/logline"
+	"github.com/jaqx0r/mtail/internal/logline"
 )
 
 type streamBase struct {
