@@ -18,8 +18,8 @@ import (
 	"sync"
 
 	"github.com/golang/glog"
-	"github.com/google/mtail/internal/logline"
-	"github.com/google/mtail/internal/waker"
+	"github.com/jaqx0r/mtail/internal/logline"
+	"github.com/jaqx0r/mtail/internal/waker"
 )
 
 var (
