@@ -9,8 +9,8 @@ import (
 	"sync"
 	"testing"
 
-	"github.com/google/mtail/internal/tailer/logstream"
-	"github.com/google/mtail/internal/testutil"
+	"github.com/jaqx0r/mtail/internal/tailer/logstream"
+	"github.com/jaqx0r/mtail/internal/testutil"
 	"golang.org/x/sys/unix"
 )
 
