@@ -17,9 +17,9 @@ import (
 	"sync"
 
 	"github.com/golang/glog"
-	"github.com/google/mtail/internal/logline"
-	"github.com/google/mtail/internal/tailer/logstream"
-	"github.com/google/mtail/internal/waker"
+	"github.com/jaqx0r/mtail/internal/logline"
+	"github.com/jaqx0r/mtail/internal/tailer/logstream"
+	"github.com/jaqx0r/mtail/internal/waker"
 )
 
 // logCount records the number of logs that are being tailed.
